package
Version:
v1.0.0
Opens a new window with list of versions in this module.
Published: Dec 23, 2021
License: MIT
Opens a new window with license information.
Imports: 6
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
GetPathTree builds ta tree from the path
IsDir checks if path is a dir
type FileData struct {
Bytes []byte
ContentType string
}
FileData is a file data structure
GetFile returns the file from a given path
Source Files
¶
Directories
¶
Click to show internal directories.
Click to hide internal directories.